@@ -1,7 +1,7 @@
 about.bear<-function(){
 cat("\n\n")
 cat(" ----------------------------------------------------------------\n\n")
-cat("  bear v2.5.8                                                      \n")
+cat("  bear v2.6.0                                                      \n")
 cat("  http://pkpd.kmu.edu.tw/bear                                      \n")  
 cat("                                                                   \n")  
 cat(" This package is designed to analyze average bioequivalence (ABE)  \n")  
@@ -17,7 +17,7 @@ cat(" crossover design/data.                                          \n\n")
 cat(" bear was developed by Hsin-ya Lee & Yung-jin Lee.                 \n")
 cat(" contact: Yung-jin Lee <mobilepk@gmail.com>                        \n")
 cat(" Kaohsiung Veterans General Hospital (HY) & ptpc inc. (YJ),        \n")
-cat(" Kaohsiung City, Taiwan                                          \n\n")
+cat(" Kaohsiung, Taiwan                                               \n\n")
 cat(" internet resources:                                               \n")
 cat(" bear's website: http://pkpd.kmu.edu.tw/bear                       \n")
 cat(" R website: http://www.r-project.org                               \n")
