@@ -3,29 +3,55 @@
 ##
 demomenu<-function(replicated=FALSE, parallel=FALSE, multiple=FALSE)
 {
-cat("\n")
 Demo<-Demo  ## set Demo as Global see go.r
 Demo<<-TRUE
 Replicateddata<-NULL
 MultipleParadata<-NULL
 Paralleldata<-NULL
+Multipledata<-NULL
+TotalSingledata<-NULL
 
-  file.menu <- c("lambda_z est. from 2-6 data points",
-                 "lambda_z est. with adjusted R sq. (ARS)",
-                 "lambda_z est. with Akaike information criterion (AIC)",
-                 "lambda_z est. with Two-Times-Tmax method (TTT)",
-                 "lambda_z est. with TTT and ARS",
-                 "lambda_z est. with TTT and AIC",
-                 "Back to the previous step",
-                 "Quit")
- cat("\n")
-  pick <- menu(file.menu, title = "  << Method Selection for of lambda_z Estimation>> ", graphics=TRUE)
+### move here since v2.5.9 [2013/11/10 AM 01:01:55] -YJ
+
+lin.AUC<-lin.AUC
+pAUC<-pAUC               ### for pAUC
+lambda_z_calc<-lambda_z_calc
+BE_LL<-BE_LL
+BE_UL<-BE_UL
+dosez<-dosez
+Tlastz<-Tlastz
+xlabz<-xlabz
+ylabz<-ylabz
+
+### 
+### file.menu <- c("Linear-up/log-down Trapezoidal Method (default)",
+###                "All with Linear Trapezoidal Method")
+### pick <- menu(file.menu, title = " << Method Selections for AUC Calculation>> ", graphics=TRUE)
+### lin.AUC<<-ifelse(pick==1,FALSE,TRUE)
+### ###
+### 
+###   file.menu <- c("Select 2-6 data points manually",
+###                  "Use Adjusted R sq. (ARS) method",
+###                  "Use Akaike information criterion (AIC) method",
+###                  "Use the Two-Times-Tmax(TTT) method",
+###                  "Use TTT and ARS method",
+###                  "Use TTT and AIC method",
+###                  "Back to the previous step",
+###                  "Quit")
+###  cat("\n")
+###   pick <- menu(file.menu, title = "  <<Method Selections for Lambda_z Estimation>> ", graphics=TRUE)
     description_NCAinput()
     
  if(replicated){
     filelocxx <- system.file("extdata", "Replicateddata.rda", package="bear")
     load(filelocxx)  ## because it is a *.rda data file
     ## saveRDS(Replicateddata,"Replicateddata_demo.RData")
+    if(file.exists("SingleRep_demo.csv")){
+       write.csv(Replicateddata,file="SingleRep_demo_02.csv",row.names=FALSE)}
+    else{write.csv(Replicateddata,file="SingleRep_demo.csv",row.names=FALSE)}
+    if(file.exists("SingleRep_demo.RData")){
+       saveRDS(Replicateddata,file="SingleRep_demo_02.RData")}
+    else{saveRDS(Replicateddata,file="SingleRep_demo.RData")}             
 
     with(entertitle.demo(), {
      description_RepNCAinput()  
@@ -84,59 +110,47 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
 create.products_sum(Totalplot)
 ###
 
-   if (pick == 1){
+   if (lambda_z_calc == 5){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         RepNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
-    if (pick == 2){
+    if (lambda_z_calc == 0){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         RepARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 3){
+    if (lambda_z_calc == 1){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         RepAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 4){
+    if (lambda_z_calc == 2){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        RepTTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 5){
+    if (lambda_z_calc == 3){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         RepTTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
          }
    else {
-    if (pick == 6){
+    if (lambda_z_calc == 4){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        RepTTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         }
-   else {
-    if (pick == 7){
-         Repmenu()
-         }       
-   else {
-    if (pick == 8){
-       cat("\n")
-       cat("\n  Thank you for using bear!  Bye now. \n")
-       graphics.off()
-              }      
-             }
-           }
         }
       }
      }
@@ -150,6 +164,12 @@ create.products_sum(Totalplot)
      filelocxx <- system.file("extdata", "MultipleParadata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
      ## saveRDS(MultipleParadata,"MultipleParadata_demo.RData")
+     if(file.exists("MultiplePara_demo.csv")){
+        write.csv(MultipleParadata,file="MultiplePara_demo_02.csv",row.names=FALSE)}
+     else{write.csv(MultipleParadata,file="MultiplePara_demo.csv",row.names=FALSE)}
+     if(file.exists("MultiplePara_demo.RData")){
+        saveRDS(MultipleParadata,file="MultiplePara_demo_02.RData")}
+     else{saveRDS(MultipleParadata,file="MultiplePara_demo.RData")}                  
      
      with(Multiplentertitle.demo(), {
      description_ParaNCAinput()  
@@ -178,60 +198,47 @@ create.products_sum(Totalplot)
 create.products_sum(Totalplot)
 ###
 
-    if (pick == 1){
+    if (lambda_z_calc == 5){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         MultipleParaNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
         }
     else {
-    if (pick == 2){
+    if (lambda_z_calc == 0){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        MultipleParaARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
-    if (pick == 3){
+    if (lambda_z_calc == 1){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        MultipleParaAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
-    if (pick == 4){
+    if (lambda_z_calc == 2){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        MultipleParaTTTdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
-    if (pick == 5){
+    if (lambda_z_calc == 3){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        MultipleParaTTTARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
    else {
-    if (pick == 6){
+    if (lambda_z_calc == 4){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        MultipleParaTTTAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
-   else {
-    if (pick == 7){
-        cat("\n")
-        MultipleParamenu()
-       }       
-   else {
-    if (pick == 8){
-       cat("\n")
-       cat("\n  Thank you for using bear!  Bye now. \n")
-       graphics.off()
-              }      
-             }
-           }
         }
       }
      }
@@ -243,6 +250,12 @@ create.products_sum(Totalplot)
      filelocxx <- system.file("extdata", "Paralleldata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
      ## saveRDS(Paralleldata,"Paralleldata_demo.RData")
+     if(file.exists("SinglePara_demo.csv")){
+        write.csv(Paralleldata,file="SinglePara_demo_02.csv",row.names=FALSE)}
+     else{write.csv(Paralleldata,file="SinglePara_demo.csv",row.names=FALSE)}
+     if(file.exists("SinglePara_demo.RData")){
+        saveRDS(Paralleldata,file="SinglePara_demo_02.RData")}
+     else{saveRDS(Paralleldata,file="SinglePara_demo.RData")}
      
      with(entertitle.demo(), {
      description_ParaNCAinput()  
@@ -267,60 +280,47 @@ create.products_sum(Totalplot)
 create.products_sum(Totalplot)
 ###
       
-    if (pick == 1){
+    if (lambda_z_calc == 5){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         ParaNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
-    if (pick == 2){
+    if (lambda_z_calc == 0){
       show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ParaARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 3){
+    if (lambda_z_calc == 1){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ParaAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 4){
+    if (lambda_z_calc == 2){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ParaTTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 5){
+    if (lambda_z_calc == 3){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ParaTTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
    else {
-    if (pick == 6){
+    if (lambda_z_calc == 4){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ParaTTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
-   else {
-    if (pick == 7){
-        cat("\n")
-        Paramenu()
-       }       
-   else {
-    if (pick == 8){
-       cat("\n")
-       cat("\n  Thank you for using bear!  Bye now. \n")
-       graphics.off()
-              }      
-             }
-           }
         }
       }
      }
@@ -333,6 +333,12 @@ else{
   if(multiple){
      filelocxx <- system.file("extdata", "Multipledata.rda", package="bear")
      load(filelocxx)
+     if(file.exists("Multiple2x2x2_demo.csv")){
+        write.csv(Multipledata,file="Multiple2x2x2_demo_02.csv",row.names=FALSE)}
+     else{write.csv(Multipledata,file="Multiple2x2x2_demo.csv",row.names=FALSE)}
+     if(file.exists("Multiple2x2x2_demo.RData")){
+        saveRDS(Multipledata,file="Multiple2x2x2_demo_02.RData")}
+     else{saveRDS(Multipledata,file="Multiple2x2x2_demo.RData")}     
      
      with(Multiplentertitle.demo(), {
      description_NCAinput()  
@@ -361,60 +367,47 @@ else{
 create.products_sum(Totalplot)
 ###
       
-    if (pick == 1){
+    if (lambda_z_calc == 5){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
         MultipleNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
         }
     else {
-    if (pick == 2){
+    if (lambda_z_calc == 0){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
        MultipleARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
-    if (pick == 3){
+    if (lambda_z_calc == 1){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
        MultipleAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
-    if (pick == 4){
+    if (lambda_z_calc == 2){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
        MultipleTTTdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
-    if (pick == 5){
+    if (lambda_z_calc == 3){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
        MultipleTTTARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
    else {
-    if (pick == 6){
+    if (lambda_z_calc == 4){
         show(SingleRdata0)
         show(SingleTdata0)
         cat("\n")
        MultipleTTTAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
-   else {
-    if (pick == 7){
-        cat("\n")
-        MultipleNCAmenu()
-       }       
-   else {
-    if (pick == 8){
-       cat("\n")
-       cat("\n  Thank you for using bear!  Bye now. \n")
-       graphics.off()
-              }      
-             }
-           }
         }
        }
       }
@@ -425,6 +418,12 @@ create.products_sum(Totalplot)
   else{   
      filelocxx <- system.file("extdata", "TotalSingledata.rda", package="bear")
      load(filelocxx)
+     if(file.exists("Single2x2x2_demo.csv")){
+        write.csv(TotalSingledata,file="Single2x2x2_demo_02.csv",row.names=FALSE)}
+     else{write.csv(TotalSingledata,file="Single2x2x2_demo.csv",row.names=FALSE)}
+     if(file.exists("Single2x2x2_demo.RData")){
+        saveRDS(TotalSingledata,file="Single2x2x2_demo_02.RData")}
+     else{saveRDS(TotalSingledata,file="Single2x2x2_demo.RData")}          
 
      with(entertitle.demo(), {
      description_NCAinput()  
@@ -449,60 +448,47 @@ create.products_sum(Totalplot)
 create.products_sum(Totalplot)
 ###
       
-    if (pick == 1){
+    if (lambda_z_calc == 5){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         NCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
-    if (pick == 2){
+    if (lambda_z_calc == 0){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        ARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 3){
+    if (lambda_z_calc == 1){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        AICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 4){
+    if (lambda_z_calc == 2){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        TTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
-    if (pick == 5){
+    if (lambda_z_calc == 3){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        TTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
    else {
-    if (pick == 6){
+    if (lambda_z_calc == 4){
         show(SingleRdata)
         show(SingleTdata)
         cat("\n")
        TTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
-   else {
-    if (pick == 7){
-        cat("\n")
-        NCAmenu()
-       }       
-   else {
-    if (pick == 8){
-       cat("\n")
-       cat("\n  Thank you for using bear!  Bye now. \n")
-       graphics.off()
-              }      
-             }
-           }
         }
        }
       }
