@@ -14,11 +14,11 @@ if(lnAUC0INF){
  theta2<-lnAUC0INF_theta2
  }  
 cat("**Interpretation:\n")
-cat("Ho: Theta < ",formatC(theta1,format="f",digits=5)," or  Theta > ",formatC(theta2,format="f",digits=5), "\n")
-cat("Ha: ",formatC(theta1,format="f",digits=5)," < or = Theta < or = ",formatC(theta2,format="f",digits=5),"\n")
+cat(paste("Ho: Theta < ",formatC(theta1,format="f",digits=3)," or  Theta > ",formatC(theta2,format="f",digits=5),"\n",sep=""))
+cat(paste("Ha: ",formatC(theta1,format="f",digits=3)," < or = Theta < or = ",formatC(theta2,format="f",digits=5),"\n",sep=""))
 cat("where Theta = Mean_Test/Mean_Ref.\n")
-cat("Because all P values are less than 0.05\n, we will reject the null hypothesis (Ho).\n")
-cat("BE acceptance criterion is set within the range of ",formatC(theta1*100,format="f",digits=3),"% -",
-     formatC(theta2*100,format="f",digits=3),"%.\n")
+cat("Because all P values are less than 0.05,\nwe will reject the null hypothesis (Ho).\n")
+cat(paste("BE acceptance criterion is set within the range of ",formatC(theta1*100,format="f",digits=3),"% - ",
+     formatC(theta2*100,format="f",digits=3),"%.\n",sep=""))
 cat("\n")
 }
\ No newline at end of file
