@@ -8,12 +8,12 @@ cat(" d88    88 d8(   )8b       )8b  888  8)            \n")
 cat(" 888    88 888ooo88b o8o89888   888                \n")
 cat(" 888    88 888       88(   88   888                \n")
 cat("   o8ooo8   88bod8P   doooo8b  d888b             \n\n")
-cat(" This report was generated using bear v2.5.8\n")
+cat(" This report was generated using bear v2.6.0\n")
 cat(" on:-",date(),"\n\n")
 cat(" bear is developed by Hsin-ya Lee & Yung-jin Lee.\n")
 cat(" contact: Yung-jin Lee <mobilepk@gmail.com> \n")
 cat(" Kaohsiung Veterans General Hospital (HY) &\n")
 cat(" ptpc inc. (YJ),\n")
-cat(" Kaohsiung City, Taiwan\n\n")
+cat(" Kaohsiung, Taiwan\n\n")
 cat("..................................................\n\n")
 }
\ No newline at end of file
