@@ -1,7 +1,12 @@
 # for statistical analysis
 statmenu<-function(multiple=FALSE)
 {
-cat("\n")
+
+designtrace<-designtrace
+dt_old<-""
+dt_old<-designtrace
+
+cat("*** You have selected the following ->\n",designtrace,"\n")
   if(multiple){
   file.menu <- c("Statistical analysis for 2x2x2 crossover study",
                  "Statistical analysis for parallel study",
@@ -11,16 +16,21 @@ cat("\n")
   pick <- menu(file.menu, title = " << Statistical analysis menu>> ", graphics=TRUE)
     if (pick == 1){
       cat("\n")
+        designtrace<<-paste(designtrace,"2x2x2 crossover,",sep=" ")
         MultipleBANOVAmenu()
         }
     else {
     if (pick == 2){
         cat("\n")
+        designtrace<<-paste(designtrace,"parallel study,",sep=" ")
         MultipleParaMIXmenu()
        }
     else {
     if (pick == 3){
         cat("\n")
+        dt_old<-gsub("stat analysis only,","",dt_old,fixed=TRUE)   ### find and replace characters in a string... -YJ
+        dt_old<-trim(dt_old)                                       ### Remove leading and trailing spaces from character strings 
+        designtrace<<-dt_old
         Multiplego()
        }
     else {
@@ -43,22 +53,28 @@ cat("\n")
   pick <- menu(file.menu, title = " << Statistical analysis menu>> ", graphics=TRUE)
     if (pick == 1){
       cat("\n")
+        designtrace<<-paste(designtrace,"2x2x2 crossover,",sep=" ")
         BANOVAmenu()
         }
     else {
     if (pick == 2){
         cat("\n")
+        designtrace<<-paste(designtrace,"replicated study,",sep=" ")
         RepMIXmenu()
        }
     else {
     if (pick == 3){
         cat("\n")
+        designtrace<<-paste(designtrace,"parallel study,",sep=" ")
         ParaMIXmenu()
        }
     else {
     if (pick == 4){
         cat("\n")
-       Singlego()
+        dt_old<-gsub("stat analysis only,","",dt_old,fixed=TRUE)   ### find and replace characters in a string... -YJ
+        dt_old<-trim(dt_old)                                       ### Remove leading and trailing spaces from character strings 
+        designtrace<<-dt_old
+        Singlego()
        }
     else {
     if (pick == 5){
